//*****************************************************************************
//  b_alert.cpp - functions to allow Small Eiffel to access the BeOS BAlert
//
//           This file is part of the SmallEiffel BeOS Library.
//                  Copyright (C) 1998 Lost Alternative
//                J. Scott Edwards - sedwards@xmission.com 
//
// This is  free  software;  you can  redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation;  either  version  2, or (at your option) any
// later verson.  It is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for  more  details.  You  should  have  received
// a copy of the GNU General Public  License  along  with this software;
// see the file COPYING.  If not, write to the  Free Software Foundation,
// Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// The original source code for SmallEiffel can be found at
//             http://www.loria.fr/SmallEiffel
//
//*****************************************************************************

#include <Alert.h>


static alert_type typeTable[] = {
    B_EMPTY_ALERT,
    B_INFO_ALERT,
    B_IDEA_ALERT,
    B_WARNING_ALERT,
    B_STOP_ALERT
};


////////////////////////////////////////////////////////////////////////////////
// Function to construct a one button alert box
////////////////////////////////////////////////////////////////////////////////

extern "C" BAlert* b_alert_construct_1(
    const char* text,
    const char* first,
    int         theType);

BAlert* b_alert_construct_1(
    const char* text,
    const char* first,
    int         theType)    // 0=Empty, 1=Info, 2=Idea, 3=Warning, 4=Stop
{
    BAlert* theAlert = new BAlert((const char*)NULL, text, first, NULL, NULL,
                                            B_WIDTH_AS_USUAL, typeTable[theType]);
    return theAlert;
}


////////////////////////////////////////////////////////////////////////////////
// Function to construct a two button alert box
////////////////////////////////////////////////////////////////////////////////

extern "C" BAlert* b_alert_construct_2(
    const char* text,
    const char* first,
    const char* second,
    int         theType);

BAlert* b_alert_construct_2(
    const char* text,
    const char* first,
    const char* second,
    int         theType)    // 0=Empty, 1=Info, 2=Idea, 3=Warning, 4=Stop
{
    BAlert* theAlert = new BAlert((const char*)NULL, text, first, second, NULL,
                                            B_WIDTH_AS_USUAL, typeTable[theType]);
    return theAlert;
}


////////////////////////////////////////////////////////////////////////////////
// Function to construct a three button alert box
////////////////////////////////////////////////////////////////////////////////

extern "C" BAlert* b_alert_construct_3(
    const char* text,
    const char* first,
    const char* second,
    const char* third,
    int         theType);

BAlert* b_alert_construct_3(
    const char* text,
    const char* first,
    const char* second,
    const char* third,
    int         theType)    // 0=Empty, 1=Info, 2=Idea, 3=Warning, 4=Stop
{
    BAlert* theAlert = new BAlert((const char*)NULL, text, first, second, third,
                                            B_WIDTH_AS_USUAL, typeTable[theType]);
    return theAlert;
}


////////////////////////////////////////////////////////////////////////////////
// Function to call the go function of the alert box
////////////////////////////////////////////////////////////////////////////////

extern "C" int b_alert_go(BAlert* theAlert);

int b_alert_go(BAlert* theAlert)
{
    return (theAlert->Go() + 1);    // return 1=first, 2=second, 3=third
}


