//*****************************************************************************
// b_application.cpp - functions to allow SmallEiffel access to BeOS BApplication
//
//           This file is part of the SmallEiffel BeOS Library.
//                  Copyright (C) 1998 Lost Alternative
//                J. Scott Edwards - sedwards@xmission.com 
//
// This is  free  software;  you can  redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation;  either  version  2, or (at your option) any
// later verson.  It is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for  more  details.  You  should  have  received
// a copy of the GNU General Public  License  along  with this software;
// see the file COPYING.  If not, write to the  Free Software Foundation,
// Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// The original source code for SmallEiffel can be found at
//             http://www.loria.fr/SmallEiffel
//
//*****************************************************************************

#include <Application.h>

#ifdef DEBUG
#include <stdio.h>  // remove this after debugging
#endif


class SEApplication : public BApplication 
{
  public:
    SEApplication(void*       target,
                  bool        (*quitRequestedCallback)(void*),
                  const char* signature);

    bool QuitRequested();

  private:
    void* target;
    bool (*quitReqCallback)(void*);
};


////////////////////////////////////////////////////////////////////////////////
// Routine to construct the application
////////////////////////////////////////////////////////////////////////////////

extern "C" SEApplication* b_application_construct(
    void*       target,
    const char* signature,
    bool        (*quitReqCallback)(void*) );

SEApplication* b_application_construct(
    void*       target,
    const char* signature,
    bool        (*quitReqCallback)(void*) )
{
#ifdef DEBUG
    printf("b_application_construct(%s)\n", signature);
#endif

    SEApplication* theApp = new SEApplication(target, quitReqCallback, signature);

    return theApp;
}


SEApplication::SEApplication(void* targ, bool (*qrc)(void*), const char* sig) :
  BApplication(sig)
{
    target = targ;
    quitReqCallback = qrc;
}


////////////////////////////////////////////////////////////////////////////////
// Routine to run the application
////////////////////////////////////////////////////////////////////////////////

extern "C" void b_application_run(SEApplication* theApp);

void b_application_run(SEApplication* theApp)
{
    theApp->Run();
}


////////////////////////////////////////////////////////////////////////////////
// Routine to post a message to the application
////////////////////////////////////////////////////////////////////////////////

extern "C" status_t b_application_post_message(SEApplication* theApp, int msgIndex);

status_t b_application_post_message(SEApplication* theApp, int msgIndex)
{
    static uint32 msgTable[] = {  // WARNING: this table must match the message
        B_QUIT_REQUESTED,         //          definitions in the Eiffel class
    };                            //          B_APPLICATION exactly.  I.E. if
                                  //          they are changed here, the must be
                                  //          changed there.

    return theApp->PostMessage(msgTable[msgIndex], theApp, NULL);
}


////////////////////////////////////////////////////////////////////////////////
// Member function to call the Eiffel quit_requested callback
////////////////////////////////////////////////////////////////////////////////

bool SEApplication::QuitRequested()
{
    bool result = (*quitReqCallback)(target);
#ifdef DEBUG
    printf("SEApplication::QuitRequested: %d\n", result);
#endif
    return result;
}

