--           This file is part of the SmallEiffel BeOS Library.
--                  Copyright (C) 1998 Lost Alternative
--                J. Scott Edwards - sedwards@xmission.com 
--
-- This is  free  software;  you can  redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation;  either  version  2, or (at your option) any
-- later verson.  It is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- General Public License for  more  details.  You  should  have  received
-- a copy of the GNU General Public  License  along  with this software;
-- see the file COPYING.  If not, write to the  Free Software Foundation,
-- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
--
-- The original source code for SmallEiffel can be found at
--             http://www.loria.fr/SmallEiffel
--
--
deferred class B_APPLICATION 
   --   
   -- Access the BApplication class in BeOS
   -- Note: there should only be one instance of this class
   --

feature {NONE}  -- Initialization

   construct(signature : STRING) is
      do
         signature.prepend("application/x-vnd.");
                       debug
                          std_output.put_string("B_APPLICATION - construct : ")
                          std_output.put_string(signature)
                          std_output.put_new_line
                       end;
         b_app_ptr := b_application_construct(signature.to_external, $quit_requested);
      end;


feature -- {NONE}  -- Access

   run is
      do
         b_application_run(b_app_ptr)
      end;


   Quit_request_message_index : INTEGER is 0;

   post_message(message_index : INTEGER) is
      do
         b_application_post_message(b_app_ptr, message_index)
      end;


feature {NONE}  -- Allow derived classes to make this decision

   want_to_quit : BOOLEAN is
      do
         Result := True        -- by default we always want to quit
      end;


feature {NONE}  -- External C routines

   b_application_construct(sig, qrc : POINTER) : POINTER is
    -- Receive the this pointer from C
      external "C_WithCurrent"
      end;

   b_application_run(t : POINTER) is
      external "C_WithoutCurrent"
      end;

   b_application_post_message(t : POINTER; index : INTEGER) is
      external "C_WithoutCurrent"
      end;


feature {NONE}  -- Callback routines

   quit_requested : BOOLEAN is
          -- called by BApplication when quitting has been requested
      do
                Result := want_to_quit
      end;


feature {NONE}  -- Implementation

   b_app_ptr : POINTER; -- this pointer to BApplication object


invariant

   ptr_non_void: b_app_ptr /= Void

end -- B_APPLICATION 

