--           This file is part of the SmallEiffel BeOS Library.
--                  Copyright (C) 1998 Lost Alternative
--                J. Scott Edwards - sedwards@xmission.com 
--
-- This is  free  software;  you can  redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation;  either  version  2, or (at your option) any
-- later verson.  It is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- General Public License for  more  details.  You  should  have  received
-- a copy of the GNU General Public  License  along  with this software;
-- see the file COPYING.  If not, write to the  Free Software Foundation,
-- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
--
-- The original source code for SmallEiffel can be found at
--             http://www.loria.fr/SmallEiffel
--
--
class B_FILE
   --   
   -- Access the BFile class in BeOS
   --
--creation


feature  -- Mode and Flags

   Read_only  : INTEGER is 0;   -- note this *MUST* match the array in b_file.cpp
   Write_only : INTEGER is 1;
   Read_write : INTEGER is 2;

feature -- Constructor

   construct_path(path : STRING; mode : INTEGER;
                       create, fail_if_exists, erase, open_at_end : BOOLEAN ) is
     -- construct an alert box with one button
      require
         mode >= Read_only
         mode <= Read_write
      do
         this := b_file_construct_path(path.to_external, mode,
                                      create, fail_if_exists, erase, open_at_end)
      ensure
         this.is_not_void
      end;

feature -- Access

   init_check : INTEGER is
      -- returns status of file after initialization
      -- 0 is good, negative numbers are bad
      require
         this.is_not_void
      do
         Result := b_file_init_check(this)
      end;

   get_size : INTEGER is
      -- returns size of file up to 2GB
      require
         this.is_not_void
      do
         Result := b_file_get_size(this)
      ensure
         Result >= 0 -- for now we will cause an error if file is too big (2GB)
      end;

   read(buffer : POINTER; size_of_buffer : INTEGER) : INTEGER is
     -- return the number of bytes read
     -- unfortunately we have to break with tradition here and pass the pointer
     -- to the native array in here because we can't pass the native_array.
      require
         init_check = 0
      do
         Result := b_file_read(this, buffer, size_of_buffer)
      end;

feature -- Destructor

   destruct is
      local
         null : POINTER  -- define a null pointer
      do
         b_file_destruct(this)
         this := null
      ensure
         this.is_void
      end;

feature {NONE} -- Implementation

   this : POINTER;

feature {NONE} -- Access external C routines

   b_file_construct_path(pth : POINTER; md : INTEGER;
                                        crt, fie, ers, oae : BOOLEAN) : POINTER is
    -- Receive the this pointer from C
      external "C_WithoutCurrent"
      end;

   b_file_init_check(t : POINTER) : INTEGER is
      external "C_WithoutCurrent"
      end;

   b_file_get_size(t : POINTER) : INTEGER is
     -- return file size up to 2GB, returns -1 for files larger than 2GB
      external "C_WithoutCurrent"
      end;

   b_file_read(t, b : POINTER; s : INTEGER) : INTEGER is
--      require
--         s > 0
      external "C_WithoutCurrent"
      end;

   b_file_destruct(t : POINTER) is
      external "C_WithoutCurrent"
      end;

end -- B_FILE

