--           This file is part of the SmallEiffel BeOS Library.
--                  Copyright (C) 1998 Lost Alternative
--                J. Scott Edwards - sedwards@xmission.com 
--
-- This is  free  software;  you can  redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation;  either  version  2, or (at your option) any
-- later verson.  It is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- General Public License for  more  details.  You  should  have  received
-- a copy of the GNU General Public  License  along  with this software;
-- see the file COPYING.  If not, write to the  Free Software Foundation,
-- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
--
-- The original source code for SmallEiffel can be found at
--             http://www.loria.fr/SmallEiffel
--
--
class B_RECT inherit
      MEMORY
   --   
   -- Access the BRect class in BeOS
   -- Inherits from memory so we can dispose of the BRect
   --

creation make

feature  -- Access
   
   this : POINTER;  -- pointer to the C++ BRect object

   left : REAL is
      do
         Result := b_rect_left(this)
      end;

   top : REAL is
      do
         Result := b_rect_top(this)
      end;

   right : REAL is
      do
         Result := b_rect_right(this)
      end;

   bottom : REAL is
      do
         Result := b_rect_bottom(this)
      end;

   width : REAL is
      do
         Result := b_rect_width(this)
      end;

   height : REAL is
      do
         Result := b_rect_height(this)
      end;

   offset_by(horizontal, vertical : REAL) is
      do
         b_rect_offset_by(this, horizontal, vertical)
      end;

feature {NONE}

   construct(l, t, r, b : REAL) is
      require
         will_have_width:  l < r
         will_have_height: t < b
      do
         this := b_rect_construct(l, t, r, b)
      end;

   dispose is
      do
         b_rect_destruct
      end;

   b_rect_construct(l, t, r, b : REAL) : POINTER is
	-- Receive the this pointer from C
      external "C_WithoutCurrent"
      end;

   b_rect_left(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_top(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_right(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_bottom(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_width(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_height(t : POINTER) : REAL is
      external "C_WithoutCurrent"
      end;

   b_rect_offset_by(t : POINTER; horizontal, vertical : REAL) is
      external "C_WithoutCurrent"
      end;

   b_rect_destruct(t : POINTER) is
      external "C_WithoutCurrent"
      end;

invariant
   has_width:  right > left
   has_height: bottom > top

end -- B_RECT

