--           This file is part of the SmallEiffel BeOS Library.
--                  Copyright (C) 1998 Lost Alternative
--                J. Scott Edwards - sedwards@xmission.com 
--
-- This is  free  software;  you can  redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation;  either  version  2, or (at your option) any
-- later verson.  It is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- General Public License for  more  details.  You  should  have  received
-- a copy of the GNU General Public  License  along  with this software;
-- see the file COPYING.  If not, write to the  Free Software Foundation,
-- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
--
-- The original source code for SmallEiffel can be found at
--             http://www.loria.fr/SmallEiffel
--
--
class BEOS_MEMORY_RESIDENT_FILE
   --   
   -- Wrapper for B_FILE class
   --

inherit
      B_FILE
         rename
            read as read_b_file
         end

creation
   make_using_path

feature {NONE} -- Creation

   make_using_path(file_path : STRING) is
      do
         path := file_path
         unload                -- file is not loaded
      end

feature

   path   : STRING   -- file name
   status : INTEGER  -- 0 buffer is loaded, -1 buffer is not loaded, -X error
   count  : INTEGER  -- number of items in buffer
   index  : INTEGER

   load : BOOLEAN is
     -- load buffer from file, returns true if successful
      local
         bytes_read : INTEGER
      do
         mode := Read_only      -- set for reading
         create := False
         fail_if_exists := False
         erase := False
         open_at_end := False
         construct_path(path, mode, create, fail_if_exists, erase, open_at_end)
         status := init_check

         if status = 0 then
            !!buffer.make(get_size)
            bytes_read := read_b_file(buffer.to_external, buffer.capacity)

            if bytes_read < 0 then -- an error occured
               status := bytes_read   -- put the error code into the status
            else
               count := bytes_read    -- put the number of bytes read into count
               check
                  count = get_size
               end
            end
         end

         destruct          -- close the file

         if status = 0 then
            Result := True
         end
      ensure
         Result = True implies status = 0
         Result = False implies status /= 0
      end

   unload is
      do
         buffer := Void  -- free up our buffer
         status := -1    -- show buffer is not loaded
         count  := 0     -- no items in
         index  := 0     -- back to the beginning
      end

   start is
      require
         status = 0
      do
         index := 0
      end

   item : CHARACTER is
      require
         status = 0
         buffer /= Void
      do
         Result := buffer.item(index)
      end

   after : BOOLEAN is
      require
         status = 0
      do
         Result := index = count
      end

   forth is
      require
         status = 0
      do
         if not after then
            index := index + 1
         end
      end

feature -- utility functions

   count_lines : INTEGER is
      require
         status = 0
      local
         i : INTEGER
         c : CHARACTER
      do
         from
            i := 0
         variant
            count - i
         until
            i = count
         loop
            c := buffer.item(i)
            if c = '%N' then
               Result := Result + 1
            end
            i := i + 1
         end         

         if c /= '%N' then
            std_output.put_string("Warning: ")
            std_output.put_string(path)
            std_output.put_string(" is missing new line character at the end.%N")
            Result := Result + 1
         end
      end

feature {NONE}  -- Implementation

   mode           : INTEGER

   create         : BOOLEAN      -- create file it it doesn't already exist
   fail_if_exists : BOOLEAN      -- if file already exists fail
   erase          : BOOLEAN      -- erase file if it exists
   open_at_end    : BOOLEAN      -- open file with pointer at end of file

   buffer         : FIXED_ARRAY[CHARACTER]

invariant

   index <= count
   count >= 0
   status <= 0      -- status can be 0 or negative
   status = 0 implies buffer /= Void
   status = -1 implies buffer = Void
   status = -1 implies count = 0

end -- BEOS_MEMORY_RESIDENT_FILE

