--           This file is part of the SmallEiffel BeOS Library.
--                  Copyright (C) 1998 Lost Alternative
--                J. Scott Edwards - sedwards@xmission.com 
--
-- This is  free  software;  you can  redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation;  either  version  2, or (at your option) any
-- later verson.  It is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- General Public License for  more  details.  You  should  have  received
-- a copy of the GNU General Public  License  along  with this software;
-- see the file COPYING.  If not, write to the  Free Software Foundation,
-- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
--
-- The original source code for SmallEiffel can be found at
--             http://www.loria.fr/SmallEiffel
--
--
class BEOS_STRING_FILE
   --   
   -- File of strings
   --

creation
   make_using_path

feature {NONE} -- Creation

   make_using_path(file_path : STRING) is
      do
         !!file.make_using_path(file_path)
         unload
      end

feature

   status : INTEGER    -- 0 buffer is loaded, -1 buffer is not loaded, -X error
   count  : INTEGER    -- number of lines in buffer
   index  : INTEGER    -- current index

   path   : STRING is  -- file name
      require
         file /= Void
      do
         Result := file.path
      end

   load : BOOLEAN is
     -- load buffer from file
      do
         if file.load then
            count := file.count_lines

std_output.put_string("BEOS_TEXT_FILE - load-count: ")
std_output.put_integer(count)
std_output.put_new_line

            !!line_buffer.make(count)

            from
               file.start
               index := 0
            invariant
               index <= count
            variant
               count - index
            until
               file.after
            loop
               line_buffer.put(read_string, index)
               index := index + 1
            end

            file.unload -- free the file buffer

            status := 0
            Result := True
         else -- file did not load correctly
            status := file.status
         end

      ensure
         Result = True implies status = 0
         Result = False implies status /= 0
         status = 0 implies line_buffer /= Void
      end

   unload is
      do
         line_buffer := Void  -- free up our buffer
         status := -1    -- show buffer is not loaded
      end

   start is
      require
         status = 0
      do
         index := 0
      end

   item : STRING is
      require
         status = 0
         line_buffer /= Void
      do
         Result := line_buffer.item(index)
      end

   after : BOOLEAN is
      require
         status = 0
      do
         Result := index = count
      end

   forth is
      require
         status = 0
      do
         if not after then
            index := index + 1
         end
      end

feature {NONE} -- Implementation

   file        : BEOS_FILE
   line_buffer : FIXED_ARRAY[STRING]

feature {NONE} -- Internal utilities

   temp_string : STRING  -- so we don't have to create this new each time

   read_string : STRING is
      do
         if temp_string = Void then
            !!temp_string.make(128)
         end

         from
            temp_string.clear
         variant
            file.count - file.index
         until
            file.after or else file.item = '%N'
         loop
            temp_string.append_character(file.item)
            file.forth
         end
         file.forth -- move past the new line
         !!Result.copy(temp_string)
      end


end -- BEOS_STRING_FILE

